Module error

Module error 

Structs

ApiError
An error returned by the Quantum AI API (non-2xx response).

Enums

Error
Error types returned by the Quantum AI SDK.

Functions

is_auth_error
Checks whether an error is an authentication APIError.
is_not_found_error
Checks whether an error is a not found APIError.
is_rate_limit_error
Checks whether an error is a rate limit APIError.

Type Aliases

Result
Result type alias for Quantum AI SDK operations.