Structs
- ApiError
- An error returned by the Quantum AI API (non-2xx response).
Enums
- Error
- Error types returned by the Quantum AI SDK.
Functions
- is_
auth_ error - Checks whether an error is an authentication APIError.
- is_
not_ found_ error - Checks whether an error is a not found APIError.
- is_
rate_ limit_ error - Checks whether an error is a rate limit APIError.
Type Aliases
- Result
- Result type alias for Quantum AI SDK operations.